@@ -1,13 +1,10 @@
-from typing import Awaitable, Callable, List, TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, Awaitable, Callable, List, Union
 
 from rich.segment import Segment
-
-from ._typing import Protocol
-
+from typing_extensions import Protocol
 
 if TYPE_CHECKING:
     from .message import Message
-    from .strip import Strip
 
 
 class MessageTarget(Protocol):
