@@ -82,7 +82,7 @@ class ScrollView(Widget):
         Returns:
             True if anything changed, or False if nothing changed.
         """
-        if self._size != size or container_size != container_size:
+        if self._size != size or self._container_size != container_size:
             self.refresh()
         if (
             self._size != size
@@ -93,7 +93,6 @@ class ScrollView(Widget):
             virtual_size = self.virtual_size
             self._container_size = size - self.styles.gutter.totals
             self._scroll_update(virtual_size)
-            self.scroll_to(self.scroll_x, self.scroll_y, animate=False)
             return True
         else:
             return False
