@@ -66,7 +66,7 @@ class Footer(Widget):
         self.refresh()
 
     def on_mount(self) -> None:
-        self.watch(self.screen, "focused", self._focus_changed)
+        self.watch(self.screen, "focused", self._focus_changed)  # type: ignore[arg-type]
 
     def _focus_changed(self, focused: Widget | None) -> None:
         self._key_text = None
@@ -130,9 +130,8 @@ class Footer(Widget):
             text.append_text(key_text)
         return text
 
-    def _on_styles_updated(self) -> None:
+    def notify_style_update(self) -> None:
         self._key_text = None
-        self.refresh()
 
     def post_render(self, renderable):
         return renderable
