@@ -1,3 +1,5 @@
+"""Provides a list item widget for use with `ListView`."""
+
 from textual import events
 from textual.message import Message
 from textual.reactive import reactive
@@ -5,6 +7,13 @@ from textual.widget import Widget
 
 
 class ListItem(Widget, can_focus=False):
+    """A widget that is an item within a `ListView`.
+
+    A `ListItem` is designed for use within a
+    [ListView][textual.widgets._list_view.ListView], please see `ListView`'s
+    documentation for more details on use.
+    """
+
     DEFAULT_CSS = """
     ListItem {
         color: $text;
@@ -27,11 +36,12 @@ class ListItem(Widget, can_focus=False):
     """
 
     highlighted = reactive(False)
+    """Is this item highlighted?"""
 
     class _ChildClicked(Message):
         """For informing with the parent ListView that we were clicked"""
 
-        pass
+        sender: "ListItem"
 
     def on_click(self, event: events.Click) -> None:
         self.post_message_no_wait(self._ChildClicked(self))
